@@ -19,7 +19,6 @@ class Request(object):
     name = "Request"
 
     REQUEST_CONFIG = settings.DEFAULT_REQUEST_CONFIG
-
     REQUEST_CONFIG["RETRY_FUNC"] = Coroutine
     REQUEST_CONFIG["VALID"] = Coroutine
 
@@ -31,6 +30,7 @@ class Request(object):
                  settings_attr=None,
                  callback=None, encoding: Optional[str] = None,
                  headers: dict = None,
+                 cookies: dict = None,
                  meta: dict = None, custom_settings: dict = None,
                  request_session=None, **aiohttp_kwargs):
         self.url = url
@@ -43,7 +43,7 @@ class Request(object):
         self.callback = callback
         self.encoding = encoding
         self.headers = headers or {}
-
+        self.cookies = cookies or {}
         self.meta = meta or {}
         self.request_session = request_session
 
@@ -53,6 +53,7 @@ class Request(object):
         self.request_settings = self.REQUEST_CONFIG
         if self.settings_attr and settings_attr.get('DEFAULT_REQUEST_CONFIG'):
             self.request_settings = settings_attr.get('DEFAULT_REQUEST_CONFIG')
+
         if custom_settings:
             self.request_settings = custom_settings
 
@@ -154,11 +155,11 @@ class Request(object):
         self.logger.info(f"<{self.method}: {self.url}>")
         if self.method == "GET":
             request_func = self.current_request_session.get(
-                self.url, headers=self.headers, ssl=self.ssl, **self.aiohttp_kwargs
+                self.url, headers=self.headers, cookies=self.cookies, ssl=self.ssl, **self.aiohttp_kwargs
             )
         else:
             request_func = self.current_request_session.post(
-                self.url, headers=self.headers, ssl=self.ssl, **self.aiohttp_kwargs
+                self.url, headers=self.headers, cookies=self.cookies, ssl=self.ssl, **self.aiohttp_kwargs
             )
         resp = await request_func
         return resp
@@ -196,4 +197,4 @@ class Request(object):
             return response
 
     def __repr__(self):
-        return f"<{self.method} {self.url}>"
\ No newline at end of file
+        return f"<{self.method} {self.url}>"
