@@ -1,12 +1,10 @@
 # -*- coding: utf-8 -*-
 
-
-
 """
 CREATE YOUR DEFAULT_CONFIG !
 
 Some configuration:
-        CONCURRENT_REQUESTS     并发数量
+        CONCURRENT_REQUESTS     线程数量
         RETRIES                 重试次数
         DOWNLOAD_DELAY          下载延时
         RETRY_DELAY             重试延时
@@ -23,13 +21,9 @@ CONCURRENT_REQUESTS = 20
 
 
 
-
 MIDDLEWARE = [
-# 'middlewares.middleware',
-            ]
-
-
-# PIPELINES = []
+    # 'middlewares.middleware',
+]
 
 
 
@@ -38,7 +32,7 @@ DEFAULT_REQUEST_CONFIG = {
     "RETRIES": 0,
     "DOWNLOAD_DELAY": 0,
     "RETRY_DELAY": 0,
-    "DOWNLOAD_TIMEOUT": 10,
+    "DOWNLOAD_TIMEOUT": 30,
 }
 
 
@@ -48,9 +42,5 @@ DEFAULT_REQUEST_CONFIG = {
 
 
 
-# CLOSESPIDER_TIMEOUT = 10
 
-
-
-
-#USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3100.0 Safari/537.36"
\ No newline at end of file
+#USER_AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/105.0.0.0 Safari/537.36"
\ No newline at end of file
