@@ -1,18 +1,14 @@
 # -*- coding: utf-8 -*-
 
-
-from asyncpy.spider import Spider
-import settings
+from asyncpy.spider import Spider,Request
 
 
 class DemoSpider(Spider):
     name = 'templates'
-    settings_attr = settings
 
     start_urls = []
 
 
-
     async def parse(self, response):
         pass
 
